@@ -231,6 +231,13 @@ def try_input(prompt, validate):
     return validate(answer)
 
 
+def as_is_case(words):
+    """
+    Keeps the words' case.
+    """
+    return words
+
+
 def alternating_case(words):
     """
     Set EVERY OTHER word to UPPER case.
@@ -247,11 +254,6 @@ def upper_case(words):
     """
     return [w.upper() for w in words]
 
-def first_upper_case(words):
-    """
-    Set First character of each word to UPPER case.
-    """
-    return [w.capitalize() for w in words]
 
 def lower_case(words):
     """
@@ -259,6 +261,14 @@ def lower_case(words):
     """
     return [w.lower() for w in words]
 
+
+def first_upper_case(words):
+    """
+    Set First character of each word to UPPER case.
+    """
+    return capitalize_case(words)
+
+
 def capitalize_case(words):
     """
     Set first letter of each words to UPPER case aka Capitalize.
@@ -283,13 +293,15 @@ def random_case(words, testing=False):
     return [make_upper(word) for word in lower_case(words)]
 
 
-CASE_METHODS = {"alternating": alternating_case,
-                "upper": upper_case,
-                "lower": lower_case,
-                "random": random_case,
-                "first": first_upper_case,
-                "capitalize":capitalize_case}
-
+CASE_METHODS = {
+    "as-is": as_is_case,
+    "lower": lower_case,
+    "upper": upper_case,
+    "first": first_upper_case,
+    "capitalize": capitalize_case,
+    "alternating": alternating_case,
+    "random": random_case
+}
 
 
 def set_case(words, method="lower", testing=False):
@@ -301,8 +313,8 @@ def set_case(words, method="lower", testing=False):
     Args:
         words (list):   word list generated by `choose_words()` or
                         `find_acrostic()`.
-        method (str):   one of {"alternating", "upper", "lower",
-                        "random"}.
+        method (str):   one of {"as-is", "lower", "upper", "first",
+                        "capitalize", "alternating", "random"}.
         testing (bool): only affects method="random".
                         If True: the random seed will be set to each word
                         prior to choosing True or False before setting the
@@ -363,6 +375,7 @@ def generate_xkcdpassword(wordlist,
             print('accepted', accepted)
         return passwd
 
+
 def randomized_delimiter_join(words, delimiters=DEFAULT_DELIMITERS):
     """
     Join the words into a password with random delimiters between each word
@@ -373,28 +386,30 @@ def randomized_delimiter_join(words, delimiters=DEFAULT_DELIMITERS):
         final_passwd += choose_delimiter(delimiters) + word
     return final_passwd
 
+
 def choose_delimiter(delimiters):
     """
     Choose a random delimiter from the list
     """
     return rng().choice(delimiters)
 
+
 def initialize_interactive_run(options):
     def n_words_validator(answer):
-            """
-            Validate custom number of words input
-            """
+        """
+        Validate custom number of words input
+        """
 
-            if isinstance(answer, str) and len(answer) == 0:
-                return options.numwords
-            try:
-                number = int(answer)
-                if number < 1:
-                    raise ValueError
-                return number
-            except ValueError:
-                sys.stderr.write("Please enter a positive integer\n")
-                sys.exit(1)
+        if isinstance(answer, str) and len(answer) == 0:
+            return options.numwords
+        try:
+            number = int(answer)
+            if number < 1:
+                raise ValueError
+            return number
+        except ValueError:
+            sys.stderr.write("Please enter a positive integer\n")
+            sys.exit(1)
 
     if not options.acrostic:
         n_words_prompt = ("Enter number of words (default {0}):\n".format(options.numwords))
@@ -440,7 +455,7 @@ class XkcdPassArgumentParser(argparse.ArgumentParser):
         self.add_argument(
             "-w", "--wordfile",
             dest="wordfile", default=None, metavar="WORDFILE",
-             help=(
+            help=(
                 "Specify that the file WORDFILE contains the list"
                 " of valid words from which to generate passphrases."
                 " Multiple wordfiles can be provided, separated by commas."
